Quantcast

Frost Priority updated.

Taracque [08-28-12 - 15:57]
Frost Priority updated.
Filename
DKCrutch.lua
diff --git a/DKCrutch.lua b/DKCrutch.lua
index b534d72..4273516 100755
--- a/DKCrutch.lua
+++ b/DKCrutch.lua
@@ -562,27 +562,27 @@ function DKCrutch:AdviseFrostAbility()
 		end
 	end

-	-- Obliterate if 2 death runes are up, or 2 frost and 2 unholy runes are up
+	-- Frost Strike if Killing Machine Procs
+	local fscd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Frost Strike"])
+	if (fscd) and (fscd <= 1) and (DKCrutch:hasBuff("player", DKCrutch.SpellList["Killing Machine"])) then
+		return "Frost Strike"
+	end
+
+	-- Obliterate if 2 death/unholy runes are up and Killing Machine Procs
 	local obcd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Obliterate"])
-	if (DKCrutch.runesUp[4] == 2) or ((DKCrutch.runesUp[2] == 2) and (DKCrutch.runesUp[3] == 2)) or (DKCrutch:hasBuff("player", DKCrutch.SpellList["Killing Machine"]))  then
+	if ((DKCrutch.runesUp[4] == 2) or (DKCrutch.runesUp[3] == 2)) and (DKCrutch:hasBuff("player", DKCrutch.SpellList["Killing Machine"]))  then
 		if (obcd) and (obcd <= 1) then
 			return "Obliterate"
 		end
 	end

-	-- Empower Rune Weapon
-	local ercd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Empower Rune Weapon"])
-	if (ercd) and (ercd <= 1) and (DKCrutch.runesUp[2] == 0) and (DKCrutch:hasBuff("player", DKCrutch.SpellList["Killing Machine"])) then
-		return "Empower Rune Weapon"
-	end
-
 	-- Frost Strike if  runic power > 90
 	local fscd = DKCrutch:GetSpellCooldownRemaining(DKCrutch.SpellList["Frost Strike"])
 	if (fscd) and (fscd <= 1) and (UnitPower("player", 6) > 90) then
 		return "Frost Strike"
 	end

-	-- Howling Blast if Freezing Fog proc, or 0 unholy and death runes are up
+	-- Howling Blast if Freezing Fog proc (Rime)
 	if (hbcd) and (hbcd <= 1) and (
 		(DKCrutch:hasBuff("player", DKCrutch.SpellList["Freezing Fog"])) or
 		((DKCrutch.runesUp[4] == 0) and (DKCrutch.runesUp[2] == 0))
@@ -595,11 +595,6 @@ function DKCrutch:AdviseFrostAbility()
 		return "Obliterate"
 	end

-	-- Empower Rune Weapon
-	if (ercd) and (ercd <= 1) then
-		return "Empower Rune Weapon"
-	end
-
 	-- Frost Strike
 	if (fscd) and (fscd <= 1) and (IsUsableSpell(DKCrutch.SpellList["Frost Strike"])) then
 		return "Frost Strike"